==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cloudngfw/kotlin/inputs/GetFirewallGlobalRulestackPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cloudngfw.kotlin.inputs

import com.pulumi.azurenative.cloudngfw.inputs.GetFirewallGlobalRulestackPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property firewallName Firewall resource name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetFirewallGlobalRulestackPlainArgs(
    public val firewallName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.cloudngfw.inputs.GetFirewallGlobalRulestackPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.cloudngfw.inputs.GetFirewallGlobalRulestackPlainArgs =
        com.pulumi.azurenative.cloudngfw.inputs.GetFirewallGlobalRulestackPlainArgs.builder()
            .firewallName(firewallName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetFirewallGlobalRulestackPlainArgs].
 */
@PulumiTagMarker
public class GetFirewallGlobalRulestackPlainArgsBuilder internal constructor() {
    private var firewallName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Firewall resource name
     */
    @JvmName("lgnrspeevukywbga")
    public suspend fun firewallName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.firewallName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("nkefxhyfkatqcvnb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetFirewallGlobalRulestackPlainArgs = GetFirewallGlobalRulestackPlainArgs(
        firewallName = firewallName ?: throw PulumiNullFieldException("firewallName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/cloudngfw/kotlin/inputs/GetFirewallGlobalRulestackPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cloudngfw.kotlin.inputs

import com.pulumi.azurenative.cloudngfw.inputs.GetFirewallGlobalRulestackPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property firewallName Firewall resource name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetFirewallGlobalRulestackPlainArgs(
    public val firewallName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.cloudngfw.inputs.GetFirewallGlobalRulestackPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.cloudngfw.inputs.GetFirewallGlobalRulestackPlainArgs = com.pulumi.azurenative.cloudngfw.inputs.GetFirewallGlobalRulestackPlainArgs.builder()
        .firewallName(firewallName.let({ args0 -> args0 }))
        .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetFirewallGlobalRulestackPlainArgs].
 */
@PulumiTagMarker
public class GetFirewallGlobalRulestackPlainArgsBuilder internal constructor() {
    private var firewallName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Firewall resource name
     */
    @JvmName("mcivhqfheqlsedny")
    public suspend fun firewallName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.firewallName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("nqsulhxkbmonegqh")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetFirewallGlobalRulestackPlainArgs = GetFirewallGlobalRulestackPlainArgs(
        firewallName = firewallName ?: throw PulumiNullFieldException("firewallName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
